@@ -3,6 +3,7 @@ from typing import Optional, List
 import os
 import time
 from io import BytesIO
+from enum import Enum
 from pathlib import Path
 from threading import Semaphore
 from concurrent.futures import ThreadPoolExecutor, as_completed
@@ -87,10 +88,16 @@ def from_tos(localpaths: List[str], remotedir: str) -> List[FromTo]:
     return ft
 
 
+class UploadType(Enum):
+    ManyToOne = 1
+    OneToMany = 1
+
+
 # remotedir must be a directory
 def upload(
     api: BaiduPCSApi,
     from_to_list: List[FromTo],
+    upload_type: UploadType = UploadType.ManyToOne,
     ondup: str = "overwrite",
     encrypt_password: bytes = b"",
     encrypt_type: EncryptType = EncryptType.No,
@@ -112,7 +119,7 @@ def upload(
         show_progress (bool): Show uploading progress.
 
         check_md5 (bool): To fix the content md5 after `combine_slices`
-            `combine_slices` always not return correct content md5. To fix it,
+            `combine_slices` always does not return correct content md5. To fix it,
             we need to use `rapid_upload_file` re-upload the content.
             Warning, if content length is large, it could take some minutes,
             e.g. it takes 5 minutes about 2GB.
@@ -322,7 +329,7 @@ def upload_file(
     content_crc32 = 0
     io_len = 0
 
-    if encrypt_io_len > 256 * constant.OneK:
+    if encrypt_type == EncryptType.No and encrypt_io_len > 256 * constant.OneK:
         # Rapid Upload
         logger.debug("`upload`: rapid_upload starts")
         try:
